Package: countdown
Title: A Countdown Timer for HTML Presentations, Documents, and Web
        Apps
Version: 0.6.0
Authors@R: 
    person("Garrick", "Aden-Buie", , "garrick@adenbuie.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-7111-0077"))
Description: A simple countdown timer for slides and HTML documents
    written in 'R Markdown' or 'Quarto'. Integrates fully into 'Shiny'
    apps. Countdown to something amazing.
License: MIT + file LICENSE
URL: https://pkg.garrickadenbuie.com/countdown/,
        https://github.com/gadenbuie/countdown
BugReports: https://github.com/gadenbuie/countdown/issues
Imports: htmltools, prismatic (>= 1.1.0), utils
Suggests: rmarkdown, shiny, testthat (>= 3.0.0)
Config/Needs/website: callr, xaringan, xaringanthemer, xaringanExtra
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-11-14 20:18:15 UTC; garrick
Author: Garrick Aden-Buie [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-7111-0077>)
Maintainer: Garrick Aden-Buie <garrick@adenbuie.com>
Repository: CRAN
Date/Publication: 2025-11-14 21:20:08 UTC
Built: R 4.6.0; ; 2026-04-26 00:17:42 UTC; unix
