Juju Countdown gDesklet v0.8
============================

This desklet allows to countdown the remaining time until a configurable 
date. It then displays a victorious 'Hurrah!', or whatever you set.

It also provides an increasing counter ('countup' feature), displaying 
the time elapsed from the specified date.

It comes with one display, one sensor and some gfx.

It also requires the LTVFontSelector sensor from Kerrick, provided 
within this archive. The sensor, not Kerrick.

-- 
Juju <juju@independentcoders.net>
